Just Read the Instructions!
===========================

Entry in PyWeek #24  <https://pyweek.org/24/>

* Team: encukou
* Members: encukou


## DEPENDENCIES

You will need Python 3.6:  http://www.python.org/

The game will *NOT* work with Python 2.



## RUNNING THE GAME

The `pyz` file can be run directly with Python. Try double-clicking it.


Othewise open a terminal / console and `cd` to the game directory and run:

    python3 jrti_game.pyz


(If running from a git clone, you'll need a virtual environment;
install with `python3 -m pip install -r requirements.txt`, then run with
`python3 -m jrti_game`.)



## WHERE IS THE SOURCE

The `pyz` file is a zip archive that contains all the source.

A repository is also available at https://github.com/encukou/jrti_game



## HOW TO PLAY THE GAME

A mouse and keyboard is necessary.

The instructions are included in the game; drag with the mouse to read them.



## LICENSE

The code of this game "Just Read the Instructions" is licensed under the MIT
license; see the file named LICENSE.

